==> birdtray_1.8.1+ds.orig.tar.xz: birdtray-1.8.1/src/translations/installer_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Russian</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Бесплатное уведомление в системном трее о новой почте для Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Интеграция с Windows</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Выберите, как интегрировать программу в Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Автозагрузка</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Автоматически запускать ${PRODUCT_NAME} после включения.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Автоматическая проверка обновлений</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Автоматическая проверка обновлений для ${PRODUCT_NAME} при запуске.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Создать программную группу</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Создана программная группа ${PRODUCT_NAME} в меню «Пуск»&gt; «Программы».</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Значок на рабочий стол</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Создать значок ${PRODUCT_NAME} на Рабочем столе.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Создать ссылку в меню Пуск</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Создать значок для ${PRODUCT_NAME} в меню Пуск.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Переводчики</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Выберите переводы для ${PRODUCT_NAME}. ${PRODUCT_NAME} выберет перевод на основе языка системы.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME} Настройки</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Ваши настройки и конфигурация выполнены в ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Лицензионное соглашение</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Запуск ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Нажмите «Удалить», чтобы начать процесс.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Удаление предыдущей версии ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Не удалось удалить старую установку ${PRODUCT_NAME}! Продолжение удалит ВСЕ в $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Ошибка при выполнении удаления.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} уже запущен. Нажмите OK, чтобы остановить ${PRODUCT_NAME} и продолжить установку.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Завершить процесс ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Не удалось закрыть ${PRODUCT_NAME}. Повторите попытку или выйдите из ${PRODUCT_NAME} вручную, чтобы продолжить установку.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} в данный момент работает. Нажмите OK для остановки ${PRODUCT_NAME}, чтобы продолжить удаление.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Не удалось закрыть ${PRODUCT_NAME}. Повторите попытку или выйдите из ${PRODUCT_NAME} вручную, чтобы продолжить удаление.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>Установка ${PRODUCT_NAME} уже запущена.$\r$\nЗакройте все её экземпляры и нажмите «Повторить», чтобы продолжить установку, или «Отмена», чтобы выйти из установки.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>Удаление ${PRODUCT_NAME} уже запущено.$\r$\n Закройте все его экземпляры и нажмите «Повторить», чтобы продолжить удаление, или «Отмена», чтобы прервать удаление.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>Путь установки не должен содержать$\r$\n${BAD_PATH_CHARS}</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>Путь установки содержит предыдущую версию ${PRODUCT_NAME}, которая будет обновлена.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>Путь установки не является пустым, но, похоже, он не содержит предыдущую установку ${PRODUCT_NAME}. Содержимое будет перезаписано.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (только текущий пользователь)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} не был полностью установлен.$\r$\n\Пожалуйста, перезапустите Windows и запустите установку снова.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} был не полностью установлен.$\r$\n\Пожалуйста, перезапустите Windows и запустите установку снова.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} не был полностью удалён.$\r$\nПожалуйста, перезапустите Windows и снова запустите программу удаления.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Ошибка удаления файла:$\r$\n$\r$\n$0$\r$\n$\r$\nНажмите Повторить, чтоб продолжить, или$\r$\nОтменить для отмены удаления.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Ошибка удаления файла $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Вы устанавливаете 32-разрядную версию ${PRODUCT_NAME} на Вашей 64-разрядной Windows. Доступна 64-разрядная версия ${PRODUCT_NAME} для загрузки.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Установщик содержит 64-разрядную версию ${PRODUCT_NAME}. На Вашем компьютере устновлена 32-разрядная версия Windows, которая не может запускать 64-разрядные программы. Пожалуйста, загрузите 32-разрядныйустановщик ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Эта программа требует как минимум Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>Удаление ${PRODUCT_NAME} было прервано. Пожалуйста, попробуйте позже.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} настройка</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>Деинсталлятор запускается с правами администратора, но для администратора, похоже, нет установки ${PRODUCT_NAME}. Вы хотите перезапустить программу удаления без прав администратора?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Открытие $0 в браузере по умолчанию...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Не обнаружен Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>На этом компьютере не найден следующий обязательный компонент:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nВы хотите загрузить установщик для компонента?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>После завершения загрузки, пожалуйста, запустите загруженный установщик. После завершения установки нажмите кнопку ОК, чтобы снова проверить состояние установки.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>Требуемый компонент уже установлен на вашем компьютере.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>Необходимый компонент не найден на вашем компьютере. Поищите в Интернете файлы для загрузки Visual C++ ${ARCH} для Visual Studio 2015 и выше.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} не сможет работать.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} не сможет запуститься, потому что отсутствует обязательный компонент.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Английский</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Немецкий</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Голландский</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Итальянский</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Португа́льский</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Испанский язык</translation>
    </message>
</context>
</TS>

==> birdtray_1.9.0+ds.orig.tar.xz: birdtray-1.9.0/src/translations/installer_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Russian</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Бесплатное уведомление в системном трее о новой почте для Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Интеграция с Windows</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Выберите, как интегрировать программу в Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Автозагрузка</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Автоматически запускать ${PRODUCT_NAME} после включения.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Автоматическая проверка обновлений</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Автоматическая проверка обновлений для ${PRODUCT_NAME} при запуске.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Создать программную группу</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Создана программная группа ${PRODUCT_NAME} в меню «Пуск»&gt; «Программы».</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Значок на рабочий стол</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Создать значок ${PRODUCT_NAME} на Рабочем столе.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Создать ссылку в меню Пуск</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Создать значок для ${PRODUCT_NAME} в меню Пуск.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Переводчики</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Выберите переводы для ${PRODUCT_NAME}. ${PRODUCT_NAME} выберет перевод на основе языка системы.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME} Настройки</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Ваши настройки и конфигурация выполнены в ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Лицензионное соглашение</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Запуск ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Нажмите «Удалить», чтобы начать процесс.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Удаление предыдущей версии ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Не удалось удалить старую установку ${PRODUCT_NAME}! Продолжение удалит ВСЕ в $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Ошибка при выполнении удаления.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} уже запущен. Нажмите OK, чтобы остановить ${PRODUCT_NAME} и продолжить установку.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Завершить процесс ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Не удалось закрыть ${PRODUCT_NAME}. Повторите попытку или выйдите из ${PRODUCT_NAME} вручную, чтобы продолжить установку.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} в данный момент работает. Нажмите OK для остановки ${PRODUCT_NAME}, чтобы продолжить удаление.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Не удалось закрыть ${PRODUCT_NAME}. Повторите попытку или выйдите из ${PRODUCT_NAME} вручную, чтобы продолжить удаление.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>Установка ${PRODUCT_NAME} уже запущена.$\r$\nЗакройте все её экземпляры и нажмите «Повторить», чтобы продолжить установку, или «Отмена», чтобы выйти из установки.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>Удаление ${PRODUCT_NAME} уже запущено.$\r$\n Закройте все его экземпляры и нажмите «Повторить», чтобы продолжить удаление, или «Отмена», чтобы прервать удаление.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>Путь установки не должен содержать$\r$\n${BAD_PATH_CHARS}</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>Путь установки содержит предыдущую версию ${PRODUCT_NAME}, которая будет обновлена.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>Путь установки не является пустым, но, похоже, он не содержит предыдущую установку ${PRODUCT_NAME}. Содержимое будет перезаписано.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (только текущий пользователь)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} не был полностью установлен.$\r$\n\Пожалуйста, перезапустите Windows и запустите установку снова.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} был не полностью установлен.$\r$\n\Пожалуйста, перезапустите Windows и запустите установку снова.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} не был полностью удалён.$\r$\nПожалуйста, перезапустите Windows и снова запустите программу удаления.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Ошибка удаления файла:$\r$\n$\r$\n$0$\r$\n$\r$\nНажмите Повторить, чтоб продолжить, или$\r$\nОтменить для отмены удаления.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Ошибка удаления файла $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Вы устанавливаете 32-разрядную версию ${PRODUCT_NAME} на Вашей 64-разрядной Windows. Доступна 64-разрядная версия ${PRODUCT_NAME} для загрузки.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Установщик содержит 64-разрядную версию ${PRODUCT_NAME}. На Вашем компьютере устновлена 32-разрядная версия Windows, которая не может запускать 64-разрядные программы. Пожалуйста, загрузите 32-разрядныйустановщик ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Эта программа требует как минимум Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>Удаление ${PRODUCT_NAME} было прервано. Пожалуйста, попробуйте позже.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} настройка</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>Деинсталлятор запускается с правами администратора, но для администратора, похоже, нет установки ${PRODUCT_NAME}. Вы хотите перезапустить программу удаления без прав администратора?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Открытие $0 в браузере по умолчанию...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Не обнаружен Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>На этом компьютере не найден следующий обязательный компонент:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nВы хотите загрузить установщик для компонента?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>После завершения загрузки, пожалуйста, запустите загруженный установщик. После завершения установки нажмите кнопку ОК, чтобы снова проверить состояние установки.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>Требуемый компонент уже установлен на вашем компьютере.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>Необходимый компонент не найден на вашем компьютере. Поищите в Интернете файлы для загрузки Visual C++ ${ARCH} для Visual Studio 2015 и выше.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} не сможет работать.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} не сможет запуститься, потому что отсутствует обязательный компонент.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Английский</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Немецкий</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Голландский</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Итальянский</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Португальский</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Испанский</translation>
    </message>
    <message>
        <source>Lang_sv</source>
        <translation>Шведский</translation>
    </message>
    <message>
        <source>Lang_tr</source>
        <translation>Турецкий</translation>
    </message>
    <message>
        <source>Lang_pl</source>
        <translation>Польский</translation>
    </message>
</context>
</TS>
